

/*
 *    SimpleGraphicalClient.java
 *    Copyright (C) 2001 New Zealand Digital Library Project
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

package org.nzdl.gsdl.SimpleGraphicalClient;

import java.awt.Dimension;
import java.awt.Toolkit;

// local libraries
import org.nzdl.gsdl.service.NzdlCollectionInfo; 
import org.nzdl.gsdl.service.NzdlQuery;
import org.nzdl.gsdl.service.NzdlRequest;
import org.nzdl.gsdl.service.NzdlResponse;
import org.nzdl.gsdl.service.NzdlResultSet;
import org.nzdl.gsdl.service.NzdlService;
import org.nzdl.gsdl.service.NzdlServiceClient;
import org.nzdl.gsdl.util.NzdlPreferences;
import org.nzdl.gsdl.util.NzdlServiceFactory;

/**
 * Class SimpleGraphicalClient
 *
 * A class to test the workings of Corba interface from the client side.
 * 
 * @author Dave Nichols (daven@cs.waikato.ac.nz)
 * @author stuart yeates (say1@cs.waikato.ac.nz)
 * @author Brett Sheeran (bsheeran@xtra.co.nz)
 * @author Gordon Paynter (paynter@cs.waikato.ac.nz)
 * @version $Revision: 2190 $
 * @see org.nzdl.gsdl.service.NzdlCollectionInfo
 * @see org.nzdl.gsdl.service.NzdlQuery
 * @see org.nzdl.gsdl.service.NzdlRequest
 * @see org.nzdl.gsdl.service.NzdlResponse
 * @see org.nzdl.gsdl.service.NzdlResultSet
 * @see org.nzdl.gsdl.service.NzdlService
 * @see org.nzdl.gsdl.service.NzdlServiceClient
 * @see org.nzdl.gsdl.util.NzdlServiceFactory;
 */


public class SimpleGraphicalClient implements Cloneable {

  CSModel csModel;
  CSFrame window;
  
  
  /** The underlying CORBA inferface */
  NzdlService nzdl = null;
 
  /** The name of the file we look for IOR's in */
  String IORFileName = "/tmp/localcorba.objid"; 
  /** The IOR that was specified on the commandline */
  String IORFromCommandLine = null;
 
  /** How verbose do we want to be ? */
  int verbosity = 2;
	
  /** 
   * Basic constructor
   */
  SimpleGraphicalClient() {
    System.err.println("in constructor");
    init(null);
  }

  /** 
   * Normal constructor
   * @param args the command line arguments
   */
  public SimpleGraphicalClient(String [] args) {
   
    init(args);
  }

  /** 
   * Do initialisation, including finding a server to connect to and
   * setting up all the GUI stuff
   * @param args the command line arguments
   */
    void init(String [] args)  {
	nzdl = NzdlServiceFactory.createNzdlService(args, 
					  System.getProperties(), 
					  null,
					  IORFileName, 
					  IORFromCommandLine);
	if (nzdl == null)
	    throw new Error("URK! unable to find an IOR...");
		
	csModel = new CSModel(nzdl);
   
	window = new CSFrame("Search via Corba", csModel);   
	Toolkit theKit = window.getToolkit();        // Get the window toolkit
	Dimension screenSize = theKit.getScreenSize();  // Get screen size

	// Set the position to screen center & size to half screen size
	/* window.setBounds(screenSize.width/4, screenSize.height/4,        // Position
	   screenSize.width/2, screenSize.height/2);      // Size
  
	*/
	window.setVisible(true);	
    } // init


  /**
   * Start the SimpleGraphicalClient 
   * @param commandline arguments (only used in ORB initialisation).
   */
	
  public static void main(String args[])
  {
		
	  System.err.println("starting...");
	  SimpleGraphicalClient sgc = new SimpleGraphicalClient();	

	  
  } //main
	
	
} // class GraphicalClient






